@@ -188,6 +188,14 @@ fluidPage(
           "Table Options",
               numericInput("sigdigits",label = "Significant Digits",value = 2,min=0,max=NA),
               sliderInput("tabletextsize", "Table Text Size", min=1, max=12,step=0.5, value=7),
+          checkboxInput('tabletextcoloroverwrite',
+                        'Overwrite Table Text Color?', value = FALSE),    
+          conditionalPanel(condition = "input.tabletextcoloroverwrite" ,
+                           colourpicker::colourInput("tabletextcolour",
+                                    "Table Text Color:",
+                                    value= "black",
+                                    showColour = "both",allowTransparent=TRUE,
+                                    returnName = TRUE)),
               sliderInput("plottotableratio", "Plot to Table Ratio", min=1, max=5,
                           value=4,step=0.25,
                           animate = FALSE),
